==> nextcloud-app-spreed-1%3A14.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/ka_GE.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "Invalid file provided" : "არასწორი ფაილი",
    "Invalid image" : "არასწორი სურათი",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "An error occurred. Please contact your admin." : "წარმოიშვა შეცდომა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "Join call" : "შეუერთდით ზარს",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "None" : "არც ერთი",
    "User" : "მომხმარებელი",
    "Disabled" : "არაა მოქმედი",
    "Users" : "მომხმარებლები",
    "Name" : "სახელი",
    "General settings" : "მთავარი პარამეტრები",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "OK" : "კარგი",
    "Checking …" : "მოწმდება ...",
    "Copy link" : "ბმულის კოპირება",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Dismiss" : "დათხოვნა",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "More actions" : "მეტი ქმედება",
    "Mute audio" : "ხმის ჩახშობა",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Grid view" : "ბადისებური ხედი",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "Back" : "უკან",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Favorite" : "რჩეული",
    "Restricted" : "აკრძალული",
    "Description" : "აღწერილობა",
    "Notifications" : "შეტყობინებები",
    "Password protection" : "პაროლით თავდაცვა",
    "Enter a password" : "შეიყვანეთ პაროლი",
    "Save" : "შენახვა",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "Password" : "პაროლი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "Calls" : "ზარები",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Loading" : "იტვირთება",
    "Groups" : "ჯგუფები",
    "Circles" : "წრეები",
    "Password protect" : "პაროლით დაცვა",
    "Close" : "დახურვა",
    "Conversation name" : "საუბრის სახელწოდება",
    "Message sent" : "წერილი გაგზავნილია",
    "Reply" : "პასუხი",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Contact" : "კონტაქტი",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "moderator" : "მოდერატორი",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Remove participant" : "მონაწილის ამოშლა",
    "No results" : "შედეგები არაა",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Details" : "დეტალები",
    "Settings" : "პარამეტრები",
    "Privacy" : "კონფიდენციალურობა",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Search" : "ძიება",
    "Send" : "გაგზავნა",
    "Files" : "ფაილები",
    "Audio" : "აუდიო",
    "Other" : "სხვა",
    "Default" : "საწყისი",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "Saved" : "დამახსოვრდა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-spreed-1%3A15.0.2-2.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/ka_GE.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "Invalid file provided" : "არასწორი ფაილი",
    "Invalid image" : "არასწორი სურათი",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Join call" : "შეუერთდით ზარს",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "None" : "არც ერთი",
    "User" : "მომხმარებელი",
    "Disabled" : "არაა მოქმედი",
    "Users" : "მომხმარებლები",
    "Name" : "სახელი",
    "General settings" : "მთავარი პარამეტრები",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "OK" : "კარგი",
    "Checking …" : "მოწმდება ...",
    "Copy link" : "ბმულის კოპირება",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Dismiss" : "დათხოვნა",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "Mute audio" : "ხმის ჩახშობა",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "Back" : "უკან",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Favorite" : "რჩეული",
    "Restricted" : "აკრძალული",
    "Description" : "აღწერილობა",
    "Personal" : "პირადი",
    "Permissions" : "უფლებები",
    "Password protection" : "პაროლით თავდაცვა",
    "Save" : "შენახვა",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "Password" : "პაროლი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "Notifications" : "შეტყობინებები",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Loading" : "იტვირთება",
    "Groups" : "ჯგუფები",
    "Circles" : "წრეები",
    "Password protect" : "პაროლით დაცვა",
    "Close" : "დახურვა",
    "Conversation name" : "საუბრის სახელწოდება",
    "Message sent" : "წერილი გაგზავნილია",
    "Reply" : "პასუხი",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Contact" : "კონტაქტი",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Create new poll" : "ახალი გამოკითხვის შექმნა",
    "Settings" : "პარამეტრები",
    "Create poll" : "გამოკითხვის შექმნა",
    "moderator" : "მოდერატორი",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Remove participant" : "მონაწილის ამოშლა",
    "No results" : "შედეგები არაა",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Details" : "დეტალები",
    "Privacy" : "კონფიდენციალურობა",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Search" : "ძიება",
    "Grid view" : "ბადისებური ხედი",
    "Send" : "გაგზავნა",
    "Files" : "ფაილები",
    "Polls" : "გამოკითხვები",
    "Audio" : "აუდიო",
    "Other" : "სხვა",
    "Default" : "საწყისი",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "An error occurred. Please contact your admin." : "წარმოიშვა შეცდომა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "Saved" : "დამახსოვრდა",
    "More actions" : "მეტი ქმედება",
    "Enter a password" : "შეიყვანეთ პაროლი",
    "Calls" : "ზარები"
},
"nplurals=2; plural=(n!=1);");
